django-sitecats documentation
=============================
https://github.com/idlesign/django-sitecats



Description
-----------

*Django reusable application for content categorization.*

Nay, - you say, - all that tags business lacks structuring.

This application is just about structuring your data: build categories hierarchy and link your site entities to those categories.



Requirements
------------

.. image:: https://idlesign.github.io/lbc/py2-lbc.svg
   :target: https://idlesign.github.io/lbc/
   :alt: LBC Python 2

----

1. Python 3.5+
2. Django 1.8+
3. Django Auth contrib enabled
4. Django Admin contrib enabled (optional)
5. django-admirarchy for Django Admin contrib (optional)
6. Django Messages contrib enabled (optional)
7. jQuery (for client side additional functionality; optional)



Table of Contents
-----------------

.. toctree::
    :maxdepth: 2

    quickstart
    toolbox
    examples
    clientside



Get involved into django-sitecats
---------------------------------

**Submit issues.** If you spotted something weird in application behavior or want to propose a feature you can do that at https://github.com/idlesign/django-sitecats/issues

**Write code.** If you are eager to participate in application development, fork it at https://github.com/idlesign/django-sitecats, write your code, whether it should be a bugfix or a feature implementation, and make a pull request right from the forked project page.

**Translate.** If want to translate the application into your native language use Transifex: https://www.transifex.com/projects/p/django-sitecats/.

**Spread the word.** If you have some tips and tricks or any other words in mind that you think might be of interest for the others — publish them.



Also
----

If the application is not what you want for content categorization / tagging, you might be interested in considering other choices — https://www.djangopackages.com/grids/g/tagging/
